<?php
// Include header file
include("header.php");

// Initialize variables
$name = $email = $password = $gender = $comments = "";
$nameErr = $emailErr = $passwordErr = $genderErr = $dateErr = $checkboxErr = "";

// PHP Arrays for Dropdowns
$months = ["Select Month", "January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];
$days = range(1, 31);
$years = range(date("Y") - 50, date("Y"));

// Check form submission
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Name validation
    if (empty($_POST["name"])) {
        $nameErr = "Name is required.";
    } else {
        $name = htmlspecialchars($_POST["name"]);
    }

    // Email validation
    if (empty($_POST["email"]) || !filter_var($_POST["email"], FILTER_VALIDATE_EMAIL)) {
        $emailErr = "Valid email is required.";
    } else {
        $email = htmlspecialchars($_POST["email"]);
    }

    // Password validation
    if (empty($_POST["password"]) || strlen($_POST["password"]) < 6) {
        $passwordErr = "Password must be at least 6 characters.";
    } else {
        $password = htmlspecialchars($_POST["password"]);
    }

    // Gender validation
    if (empty($_POST["gender"])) {
        $genderErr = "Gender selection is required.";
    } else {
        $gender = $_POST["gender"];
    }

    // Checkbox validation (bonus)
    if (!isset($_POST["interests"])) {
        $checkboxErr = "At least one interest must be selected.";
    }

    // Date validation (bonus)
    if ($_POST["month"] == "Select Month" || empty($_POST["day"]) || empty($_POST["year"])) {
        $dateErr = "Please select a valid date.";
    }

    // If no errors, redirect to display page
    if (empty($nameErr) && empty($emailErr) && empty($passwordErr) && empty($genderErr) && empty($dateErr) && empty($checkboxErr)) {
        header("Location: display.php?name=$name&email=$email&gender=$gender");
        exit();
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Registration Form</title>
    <style>
        body {
            background: linear-gradient(to right, #ff9a9e, #fad0c4);
            font-family: Arial, sans-serif;
            text-align: center;
            padding: 20px;
        }
        .container {
            background: white;
            border-radius: 10px;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.2);
            padding: 20px;
            max-width: 500px;
            margin: 0 auto;
            text-align: left;
        }
        h1 {
            color: #d14789;
        }
        label {
            font-weight: bold;
            display: block;
            margin-top: 10px;
        }
        input, select, textarea, button {
            font-size: 16px;
            padding: 8px;
            width: 100%;
            border: 1px solid #d14789;
            border-radius: 5px;
            box-sizing: border-box;
            margin-top: 5px;
        }
        button {
            background: #d14789;
            color: white;
            border: none;
            transition: background 0.3s;
            cursor: pointer;
            margin-top: 15px;
        }
        button:hover {
            background: #b23572;
        }
        .error {
            color: red;
            font-size: 14px;
        }
        .checkbox-group input, .radio-group input {
            width: auto;
            margin-right: 10px;
        }
    </style>
</head>
<body>

<h1>User Registration</h1>

<div class="container">
    <form method="POST" action="">
        <label>Name:</label>
        <input type="text" name="name" value="<?php echo $name; ?>">
        <span class="error"><?php echo $nameErr; ?></span><br><br>

        <label>Email:</label>
        <input type="text" name="email" value="<?php echo $email; ?>">
        <span class="
